<?php

namespace ACL\Repositories;

use ACL\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class Relacionaparc extends RepositoryBase {

    Use TQuery;

    protected $table = 'RELACIONAPARC';

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        parent::__construct($this->table);
        $this->entityManager = $entityManager;
    }

    public function updateIdativoInRelacionaparc($cdoperultatu, $nrorg, $nrparcnegocio, $idativo)
    {
        $query = "UPDATE RELACIONAPARC
                      SET IDATIVO         = :IDATIVO,
                          CDOPERULTATU    = :CDOPERULTATU,
                          NRORGULTATU     = :NRORGULTATU,
                          DTULTATU        = SYSDATE
                    WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG
                      AND NRTIPORELACIONA = :NRTIPORELACIONA";

        $params = array(
            "NRORG"           => $nrorg,
            "NRPARCNEGOCIO"   => $nrparcnegocio,
            "NRORGULTATU"     => $nrorg,
            "CDOPERULTATU"    => $cdoperultatu,
            "IDATIVO"         => $idativo,
            "NRTIPORELACIONA" => 25
        );

        try{
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->executeQuery($params);
        }
        catch(\Exception $e){
            throw new \Exception($e->getMessage());
        };
    }

    public function hasRelacionaparc($nrorg, $nrparcnegocio, $cdcliente)
    {
        $query = "SELECT COUNT(*) AS COUNT
                     FROM RELACIONAPARC
                    WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG
                      AND NRTIPORELACIONA = :NRTIPORELACIONA
                      AND NRPARCNEGOCIO  IN (SELECT NRPARCNEGOCIO
                                               FROM CLIENTE
                                              WHERE CDCLIENTE = :CDCLIENTE
                                                AND NRORG     = :NRORG)";

        $params = array(
            "NRORG"           => $nrorg,
            "NRTIPORELACIONA" => 25,
            "NRPARCNEGOCIO"   => $nrparcnegocio,
            "CDCLIENTE"       => $cdcliente
        );

        try{
            $result = $this->entityManager->getConnection()->fetchAllAssociative($query, $params);
            return $result[0]["COUNT"];
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        };
    }
}
